@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -122,6 +125,42 @@ class HubServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return HubServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> HubServiceTransport:
         """Returns the transport used by the client instance.
@@ -193,6 +232,26 @@ class HubServiceAsyncClient:
     ) -> pagers.ListHubsAsyncPager:
         r"""Lists hubs in a given project.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_list_hubs():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.ListHubsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_hubs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.ListHubsRequest, dict]):
                 The request object. Request for
@@ -220,7 +279,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -273,6 +332,25 @@ class HubServiceAsyncClient:
     ) -> hub.Hub:
         r"""Gets details about the specified hub.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_get_hub():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.GetHubRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_hub(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.GetHubRequest, dict]):
                 The request object. Request for
@@ -293,16 +371,19 @@ class HubServiceAsyncClient:
 
         Returns:
             google.cloud.networkconnectivity_v1.types.Hub:
-                A hub is essentially a collection of
-                spokes. A single hub can contain spokes
-                from multiple regions. However, all of a
-                hub's spokes must be associated with
-                resources that reside in the same VPC
-                network.
+                A hub is a collection of spokes. A
+                single hub can contain spokes from
+                multiple regions. However, if any of a
+                hub's spokes use the data transfer
+                feature, the resources associated with
+                those spokes must all reside in the same
+                VPC network. Spokes that do not use data
+                transfer can be associated with any VPC
+                network in your project.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -351,6 +432,30 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new hub in the specified project.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_create_hub():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.CreateHubRequest(
+                    parent="parent_value",
+                    hub_id="hub_id_value",
+                )
+
+                # Make the request
+                operation = client.create_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.CreateHubRequest, dict]):
                 The request object. Request for
@@ -369,7 +474,7 @@ class HubServiceAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             hub_id (:class:`str`):
-                Optional. A unique identifier for the
+                Required. A unique identifier for the
                 hub.
 
                 This corresponds to the ``hub_id`` field
@@ -385,14 +490,17 @@ class HubServiceAsyncClient:
             google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be :class:`google.cloud.networkconnectivity_v1.types.Hub` A hub is essentially a collection of spokes. A single hub can contain spokes
-                   from multiple regions. However, all of a hub's spokes
-                   must be associated with resources that reside in the
-                   same VPC network.
+                The result type for the operation will be :class:`google.cloud.networkconnectivity_v1.types.Hub` A hub is a collection of spokes. A single hub can contain spokes from
+                   multiple regions. However, if any of a hub's spokes
+                   use the data transfer feature, the resources
+                   associated with those spokes must all reside in the
+                   same VPC network. Spokes that do not use data
+                   transfer can be associated with any VPC network in
+                   your project.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, hub, hub_id])
         if request is not None and has_flattened_params:
@@ -453,6 +561,29 @@ class HubServiceAsyncClient:
         r"""Updates the description and/or labels of the
         specified hub.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_update_hub():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.UpdateHubRequest(
+                )
+
+                # Make the request
+                operation = client.update_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.UpdateHubRequest, dict]):
                 The request object. Request for
@@ -486,14 +617,17 @@ class HubServiceAsyncClient:
             google.api_core.operation_async.AsyncOperation:
                 An object representing a long-running operation.
 
-                The result type for the operation will be :class:`google.cloud.networkconnectivity_v1.types.Hub` A hub is essentially a collection of spokes. A single hub can contain spokes
-                   from multiple regions. However, all of a hub's spokes
-                   must be associated with resources that reside in the
-                   same VPC network.
+                The result type for the operation will be :class:`google.cloud.networkconnectivity_v1.types.Hub` A hub is a collection of spokes. A single hub can contain spokes from
+                   multiple regions. However, if any of a hub's spokes
+                   use the data transfer feature, the resources
+                   associated with those spokes must all reside in the
+                   same VPC network. Spokes that do not use data
+                   transfer can be associated with any VPC network in
+                   your project.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([hub, update_mask])
         if request is not None and has_flattened_params:
@@ -550,6 +684,29 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes the specified hub.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_delete_hub():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.DeleteHubRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.DeleteHubRequest, dict]):
                 The request object. The request for
@@ -587,7 +744,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -643,6 +800,27 @@ class HubServiceAsyncClient:
         r"""Lists the spokes in the specified project and
         location.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_list_spokes():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.ListSpokesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_spokes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.ListSpokesRequest, dict]):
                 The request object. The request for
@@ -668,7 +846,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -721,6 +899,25 @@ class HubServiceAsyncClient:
     ) -> hub.Spoke:
         r"""Gets details about the specified spoke.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_get_spoke():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.GetSpokeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_spoke(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.GetSpokeRequest, dict]):
                 The request object. The request for
@@ -753,7 +950,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -803,6 +1000,31 @@ class HubServiceAsyncClient:
         r"""Creates a spoke in the specified project and
         location.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_create_spoke():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.CreateSpokeRequest(
+                    parent="parent_value",
+                    spoke_id="spoke_id_value",
+                )
+
+                # Make the request
+                operation = client.create_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.CreateSpokeRequest, dict]):
                 The request object. The request for
@@ -820,7 +1042,7 @@ class HubServiceAsyncClient:
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
             spoke_id (:class:`str`):
-                Optional. Unique id for the spoke to
+                Required. Unique id for the spoke to
                 create.
 
                 This corresponds to the ``spoke_id`` field
@@ -849,7 +1071,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, spoke, spoke_id])
         if request is not None and has_flattened_params:
@@ -909,6 +1131,28 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of the specified spoke.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_update_spoke():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.UpdateSpokeRequest(
+                )
+
+                # Make the request
+                operation = client.update_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.UpdateSpokeRequest, dict]):
                 The request object. Request for
@@ -955,7 +1199,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([spoke, update_mask])
         if request is not None and has_flattened_params:
@@ -1014,6 +1258,29 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes the specified spoke.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1
+
+            def sample_delete_spoke():
+                # Create a client
+                client = networkconnectivity_v1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1.DeleteSpokeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1.types.DeleteSpokeRequest, dict]):
                 The request object. The request for
@@ -1051,7 +1318,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
