@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -120,6 +123,42 @@ class HubServiceAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return HubServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> HubServiceTransport:
         """Returns the transport used by the client instance.
@@ -191,6 +230,26 @@ class HubServiceAsyncClient:
     ) -> pagers.ListHubsAsyncPager:
         r"""Lists Hubs in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_list_hubs():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.ListHubsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_hubs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.ListHubsRequest, dict]):
                 The request object. Request for
@@ -218,7 +277,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -271,6 +330,25 @@ class HubServiceAsyncClient:
     ) -> hub.Hub:
         r"""Gets details of a single Hub.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_get_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.GetHubRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_hub(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.GetHubRequest, dict]):
                 The request object. Request for
@@ -291,8 +369,8 @@ class HubServiceAsyncClient:
 
         Returns:
             google.cloud.networkconnectivity_v1alpha1.types.Hub:
-                Network Connectivity Center is a hub-
-                nd-spoke abstraction for network
+                Network Connectivity Center is a
+                hub-and-spoke abstraction for network
                 connectivity management in Google Cloud.
                 It reduces operational complexity
                 through a simple, centralized
@@ -301,7 +379,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -350,6 +428,29 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Hub in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_create_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.CreateHubRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                operation = client.create_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.CreateHubRequest, dict]):
                 The request object. Request for
@@ -394,7 +495,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, hub, hub_id])
         if request is not None and has_flattened_params:
@@ -454,6 +555,28 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Hub.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_update_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.UpdateHubRequest(
+                )
+
+                # Make the request
+                operation = client.update_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.UpdateHubRequest, dict]):
                 The request object. Request for
@@ -495,7 +618,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([hub, update_mask])
         if request is not None and has_flattened_params:
@@ -552,6 +675,29 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Hub.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_delete_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.DeleteHubRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.DeleteHubRequest, dict]):
                 The request object. The request for
@@ -589,7 +735,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -644,6 +790,26 @@ class HubServiceAsyncClient:
     ) -> pagers.ListSpokesAsyncPager:
         r"""Lists Spokes in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_list_spokes():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.ListSpokesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_spokes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.ListSpokesRequest, dict]):
                 The request object. The request for
@@ -669,7 +835,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -722,6 +888,25 @@ class HubServiceAsyncClient:
     ) -> hub.Spoke:
         r"""Gets details of a single Spoke.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_get_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.GetSpokeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_spoke(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.GetSpokeRequest, dict]):
                 The request object. The request for
@@ -747,7 +932,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -796,6 +981,29 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Spoke in a given project and location.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_create_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.CreateSpokeRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                operation = client.create_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.CreateSpokeRequest, dict]):
                 The request object. The request for
@@ -838,7 +1046,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, spoke, spoke_id])
         if request is not None and has_flattened_params:
@@ -898,6 +1106,28 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Spoke.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_update_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.UpdateSpokeRequest(
+                )
+
+                # Make the request
+                operation = client.update_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.UpdateSpokeRequest, dict]):
                 The request object. Request for
@@ -938,7 +1168,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([spoke, update_mask])
         if request is not None and has_flattened_params:
@@ -997,6 +1227,29 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Spoke.
 
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_delete_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.DeleteSpokeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.DeleteSpokeRequest, dict]):
                 The request object. The request for
@@ -1034,7 +1287,7 @@ class HubServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
