@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -306,6 +308,73 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -356,50 +425,22 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, HubServiceTransport):
             # transport is a HubServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -411,6 +452,15 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -434,6 +484,27 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> pagers.ListHubsPager:
         r"""Lists Hubs in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_list_hubs():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.ListHubsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_hubs(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.ListHubsRequest, dict]):
                 The request object. Request for
@@ -461,7 +532,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -514,6 +585,26 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> hub.Hub:
         r"""Gets details of a single Hub.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_get_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.GetHubRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_hub(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.GetHubRequest, dict]):
                 The request object. Request for
@@ -534,8 +625,8 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         Returns:
             google.cloud.networkconnectivity_v1alpha1.types.Hub:
-                Network Connectivity Center is a hub-
-                nd-spoke abstraction for network
+                Network Connectivity Center is a
+                hub-and-spoke abstraction for network
                 connectivity management in Google Cloud.
                 It reduces operational complexity
                 through a simple, centralized
@@ -544,7 +635,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -593,6 +684,30 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Creates a new Hub in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_create_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.CreateHubRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                operation = client.create_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.CreateHubRequest, dict]):
                 The request object. Request for
@@ -637,7 +752,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, hub, hub_id])
         if request is not None and has_flattened_params:
@@ -697,6 +812,29 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single Hub.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_update_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.UpdateHubRequest(
+                )
+
+                # Make the request
+                operation = client.update_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.UpdateHubRequest, dict]):
                 The request object. Request for
@@ -738,7 +876,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([hub, update_mask])
         if request is not None and has_flattened_params:
@@ -795,6 +933,30 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single Hub.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_delete_hub():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.DeleteHubRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_hub(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.DeleteHubRequest, dict]):
                 The request object. The request for
@@ -832,7 +994,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -887,6 +1049,27 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> pagers.ListSpokesPager:
         r"""Lists Spokes in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_list_spokes():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.ListSpokesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_spokes(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.ListSpokesRequest, dict]):
                 The request object. The request for
@@ -912,7 +1095,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -965,6 +1148,26 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> hub.Spoke:
         r"""Gets details of a single Spoke.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_get_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.GetSpokeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_spoke(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.GetSpokeRequest, dict]):
                 The request object. The request for
@@ -990,7 +1193,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1039,6 +1242,30 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Creates a new Spoke in a given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_create_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.CreateSpokeRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                operation = client.create_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.CreateSpokeRequest, dict]):
                 The request object. The request for
@@ -1081,7 +1308,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, spoke, spoke_id])
         if request is not None and has_flattened_params:
@@ -1141,6 +1368,29 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single Spoke.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_update_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.UpdateSpokeRequest(
+                )
+
+                # Make the request
+                operation = client.update_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.UpdateSpokeRequest, dict]):
                 The request object. Request for
@@ -1181,7 +1431,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([spoke, update_mask])
         if request is not None and has_flattened_params:
@@ -1240,6 +1490,30 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single Spoke.
 
+
+        .. code-block::
+
+            from google.cloud import networkconnectivity_v1alpha1
+
+            def sample_delete_spoke():
+                # Create a client
+                client = networkconnectivity_v1alpha1.HubServiceClient()
+
+                # Initialize request argument(s)
+                request = networkconnectivity_v1alpha1.DeleteSpokeRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_spoke(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.networkconnectivity_v1alpha1.types.DeleteSpokeRequest, dict]):
                 The request object. The request for
@@ -1277,7 +1551,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
